from django.shortcuts import render
from django.contrib.auth.decorators import login_required, permission_required
from . import __title__


@login_required
@permission_required('discordpingformatter.basic_access')
def index(request):
    context = {
        'title': __title__
    }

    return render(request, 'discordpingformatter/index.html', context)



from django.apps import AppConfig
from . import __version__


class AaDiscordPingFormatterConfig(AppConfig):
    name = 'discordpingformatter'
    label = 'discordpingformatter'
    verbose_name = 'AA Discord Ping Formatter v{}'.format(__version__)
